"""
Example of using two SNAP wireless nodes to replace a RS-232 cable
Edit this script to specify the OTHER node's address, and load it into a node
Node addresses are the last three bytes of the MAC Address
MAC Addresses can be read off of the SNAP Engine sticker
For example, a node with MAC Address 001C2C1E 86001B67 is address 001B67
In SNAPpy format this would be address "\x00\x1B\x67"

Modified code written by J.C. Woltz
Further modified by Solarbotics Sept. 2011

Hardware used: Solarbotics FTDI-Synapse Adapter Kit + Syanpse Wireless RF100 module
"""
from synapse.switchboard import *
from synapse.platforms import *
otherNodeAddr = "\x00\x92\x3B"      # <= put the address of the Arduino-side node here
@setHook(HOOK_STARTUP)
def startupEvent():
    saveNvParam(13, 0)              #Buffering Timeout, Default value: 5
    saveNvParam(14, 100)            #Buffering Threshold, Default value: 75
    saveNvParam(15, 10)             #Inter-character Timeout settings, Default value: 0
    initUart(1, 1)                  #set UART1 baud rate to bootloader speed of Arduino UNO 115200kbps
    flowControl(1, False)           #set UART1 flow control to off 
    crossConnect(DS_UART1, DS_TRANSPARENT)  #set up UART1 for Transparent serial communication
    ucastSerial(otherNodeAddr)      #set the destination node of our serial transmission
    setPinDir(9, True)              #set node GPIO 9 to Output
    writePin(9, True)               #set pin High 
    setPinDir(10, False)            #set node GPIO 10 to Input
    monitorPin(10, True)            #monitor changes to the FTDI RTS pin
    setRate(3)                      #setting 3 = 1mS intervals of pin monitoring
    
@setHook(HOOK_GPIN)                 #function to Reset Arduino when uploading code
def pinChg(pinNum, isSet):
    if (isSet == False):
        rpc(otherNodeAddr, 'pulsePin', 9, 1000, True) #set GPIO 9 as a 1S reset pulse on the Arduino-side node  
    else:
        rpc(otherNodeAddr, 'writePin', 9, False) #set GPIO 9 low on the Arduino-side node
